==> graalvm-jdk-24.0.2_macos-aarch64_bin.tar.gz: com/oracle/svm/core/jvmstat/CHeapPerfMemoryProvider.java <==
/*
 * Copyright (c) 2022, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.jvmstat;

import java.nio.ByteBuffer;

import org.graalvm.word.Pointer;
import org.graalvm.word.WordFactory;

import com.oracle.svm.core.jdk.DirectByteBufferUtil;
import com.oracle.svm.core.memory.NativeMemory;
import com.oracle.svm.core.nmt.NmtCategory;

/**
 * Allocates a buffer with a minimal size that only contains the performance data header (see
 * {@link PerfMemoryPrologue}).
 */
public class CHeapPerfMemoryProvider implements PerfMemoryProvider {
    private Pointer memory;

    @Override
    public ByteBuffer create() {
        int size = PerfMemoryPrologue.getPrologueSize();
        memory = NativeMemory.calloc(size, NmtCategory.JvmStat);
        return DirectByteBufferUtil.allocate(memory.rawValue(), size);
    }

    @Override
    public void teardown() {
        if (memory.isNonNull()) {
            NativeMemory.free(memory);
            memory = WordFactory.nullPointer();
        }
    }
}

==> graalvm-jdk-25.0.1_macos-aarch64_bin.tar.gz: com/oracle/svm/core/jvmstat/CHeapPerfMemoryProvider.java <==
/*
 * Copyright (c) 2022, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.jvmstat;

import java.nio.ByteBuffer;

import jdk.graal.compiler.word.Word;
import org.graalvm.word.Pointer;

import com.oracle.svm.core.jdk.DirectByteBufferUtil;
import com.oracle.svm.core.memory.NativeMemory;
import com.oracle.svm.core.nmt.NmtCategory;

/**
 * Allocates a buffer with a minimal size that only contains the performance data header (see
 * {@link PerfMemoryPrologue}).
 */
public class CHeapPerfMemoryProvider implements PerfMemoryProvider {
    private Pointer memory;

    @Override
    public ByteBuffer create() {
        int size = PerfMemoryPrologue.getPrologueSize();
        memory = NativeMemory.calloc(size, NmtCategory.JvmStat);
        return DirectByteBufferUtil.allocate(memory.rawValue(), size);
    }

    @Override
    public void teardown() {
        if (memory.isNonNull()) {
            NativeMemory.free(memory);
            memory = Word.nullPointer();
        }
    }
}
